function genfapData
%
% IN:
% n m k
% i1 j1 w_{i1,j1}
% i2 j2 w_{i2,j2}
%
% The weighted graph G is to be partitioned into k subsets
% to minimize the total weight of the uncut edges.
% If w_{ij} > 900 (in fact, the file contains 1000 for each such
% pair), then i and j must be in different sets.
%
% OUT:
%
% The sedumi formulation of
%
%  Min C*X
%  st. X psd
%      X_{ii}      = 1 (i=1,..,n)
%      X_{ij}      = -1/(k-1) if w_{ij} > 900
%      X_{ij}     >= -1/(k-1) else
%
% where C = (1/2k) * [ Diag(We) + (k-1)W ]
% with W = (w_{ij})
%
% The user must modify the file, according what the
% I/O will be, at the positions marked with '!!!'
%
%
%
% In case you also want to solve the problem using sedumi, you
% must call
%
% x = sedumi(A, b, c, K);
% X = mat( x( (n_geq+1):(n_geq+n*n) ) );
%

src = '/home/wenzw/code/ConvexOpt/SDP/DIMACS/all/';

Probname = {'fap09', 'fap25', 'fap36'};

Probname = {'fap01', 'fap02', 'fap03', 'fap04', 'fap05', 'fap06' 'fap07', 'fap08', 'fap09','fap10', 'fap11', 'fap12', 'fap25', 'fap36'};


Probinf = [ ];

nprob = length(Probname);

Problist = [1:nprob];
% Problist = [1:3];
% Problist = [1];


for di = 1:length(Problist)
    name = Probname{Problist(di)};
    % !!!
    infile   = fopen(strcat(src, name,'.dat'), 'r');

    %
    % Read data
    %

    n = fscanf(infile, '%d', 1);
    m = fscanf(infile, '%d', 1);
    k = fscanf(infile, '%d', 1);
    data = fscanf(infile, '%d %d %f', [3,m]);
    data = data';

    %
    % Arrange data so that the first column is
    % always less than the second
    % We check that edges are NOT given twice
    % as both (i,j) and (j,i)
    %

    flipdata      = zeros( size(data,1), 2);
    flipdata(:,1) = data(:,2);
    flipdata(:,2) = data(:,1);

    l = ( data(:,1)>data(:,2) );
    data(l, 1:2) = flipdata(l, 1:2);
    

    %
    %
    % Construct sets ind_eqk, ind_eq1, ind_geq
    %
    % i*(n-1) + j is contained in the vector ind_eqk
    % <==> c{ij} > 900
    % <==> X_{ij} = -1/(k-1) is a constraint
    %
    % i*(n-1) + i is contained in the vector ind_eq1
    % for i=1,..,n, since
    % X_{ii} = 1   is  a constraint
    %
    % ind_geq is the
    % complement set of (ind_eq1  union ind_eqk)
    %

    C = sparse( data(:,1), data(:,2), data(:,3), n, n );
    
    % checking data 
    T = logical(C);
    ndiag = full(sum(diag(T)));

    % Be careful, only take the upper triangle matrix of T
    if ndiag > 0 
        error('there is diagonal elements in the index set');
    end
        
    TL = tril(T);
    if sum(sum(TL)) > 0
        error('the lower triangle matrix should be zero');
    end

    eq  = C ~= 0;
    eqk = C > 900;          p = nnz(eqk);
    geq = eq & ~eqk;        q = nnz(geq);
    
    
%     fprintf('m: %d, nnz(eq): %d, p: %d, q: %d,  p+q: %d\n', ...
%                 m, nnz(eq), p, q, p+q);
    
    if (m ~= p +q)
        error('m~= p+q Please check!');
    end
       
    [row,col] = find(eqk);
    E = [row, col];
    IE = (col-1)*n+row;
    
    [row,col] = find(geq);
    E = [E; [row, col]];
    IE = [IE; (col-1)*n+row];

    
    %
    % Construct the matrix C
    %
    
    C(eqk) = 0;
    
    C = C+C';
    C = (1/(2*k))*(diag(sum(C,1)) + (k-1)*C);
    
    % total number of constraints
    m = m + n;

   save(strcat(src, name,'_Alt.mat'), 'C', 'E', 'IE', 'n','m','k','p','q' );

    
end







